@@ -47,6 +47,9 @@ class MGEngine:
             alpha_pred = alpha_pred.astype(np.uint8)
             alpha_pred = alpha_pred[32:h + 32, 32:w + 32]
 
+            h, w = image_dict['src_shape'][:2]
+            alpha_pred = cv2.resize(alpha_pred, (w, h), interpolation=cv2.INTER_AREA)
+
             return alpha_pred
 
     def generator_tensor_dict(self, image_path, mask_path, guidance_thres=128):
@@ -58,12 +61,22 @@ class MGEngine:
         image = cv2.imread(image_path)
         mask = cv2.imread(mask_path, 0)
 
+        src_shape = mask.shape
+
+        image = cv2.resize(image, (512, 512), interpolation=cv2.INTER_AREA)
+        mask = cv2.resize(mask, (512, 512), interpolation=cv2.INTER_AREA)
+
         # only keep FG part of trimap
         mask = (mask >= guidance_thres).astype(np.float32)
 
         # mask = mask.astype(np.float32) / 255.0 ### soft trimap
 
-        sample = {'image': image, 'mask': mask, 'alpha_shape': mask.shape}
+        sample = {
+            'image': image,
+            'mask': mask,
+            'alpha_shape': mask.shape,
+            'src_shape': src_shape
+        }
 
         # reshape
         h, w = sample["alpha_shape"]
